// src/index.ts
import { PurgeCSS } from "purgecss";
import crypto from "crypto";

// src/deprecated/templates/get-template-path.ts
var templates = {
  blade: "resources/views/**/*.blade.php",
  svelte: "resources/{js,views}/**/*.svelte",
  vue: "resources/{js,views}/**/*.vue",
  react: "resources/{js,views}/**/*.{tsx,ts,jsx,js,html}",
  angular: "resources/{js,views}/**/*.html"
};
var get_template_path_default = (template) => {
  if (!(template in templates))
    throw new Error(`Template ${template} is not supported`);
  return templates[template];
};

// src/deprecated/templates/process-templates.ts
var process_templates_default = (templates2) => {
  const paths = [];
  if (templates2?.length > 0) {
    console.warn(
      `
[@erbelion/vite-plugin-laravel-purgecss] The "templates" option is deprecated and will be removed in a future release. Please use "paths" instead.`
    );
  }
  templates2?.forEach((template) => paths.push(get_template_path_default(template)));
  return paths;
};

// src/filter-options.ts
var filter_options_default = (options) => {
  const paths = [];
  options?.paths?.forEach((path) => paths.push(path));
  paths.concat(process_templates_default(options?.templates));
  if (paths.length === 0) {
    paths.push("resources/{js,views}/**/*.{blade.php,svelte,vue,html}");
  }
  const rehash = options?.rehash !== void 0 ? options.rehash : true;
  const purgeOptions = options;
  const keysToDelete = ["css", "content", "paths", "templates", "rehash"];
  if (purgeOptions) {
    keysToDelete.forEach((key) => delete purgeOptions[key]);
  }
  return {
    paths,
    purgeOptions,
    rehash
  };
};

// src/index.ts
var isOutputAsset = (bundle) => bundle.type === "asset";
var hash = (content) => crypto.createHash("sha256").update(content).digest("hex").slice(0, 8);
var index_default = (_options) => {
  return {
    name: "vite-plugin-laravel-purgecss",
    enforce: "post",
    async generateBundle(_, bundle) {
      const { paths, purgeOptions, rehash } = filter_options_default(_options);
      const cssFiles = Object.keys(bundle).filter(
        (key) => key.endsWith(".css")
      );
      if (!cssFiles) return;
      for (const file of cssFiles) {
        const asset = bundle[file];
        if (!isOutputAsset(asset)) continue;
        const purged = await new PurgeCSS().purge({
          content: paths,
          css: [{ raw: asset.source }],
          ...purgeOptions
        });
        const newCss = purged[0].css;
        if (!rehash) {
          asset.source = newCss;
          continue;
        }
        const newFileName = file.replace(
          /\.css$/,
          `-${hash(newCss)}.css`
        );
        delete bundle[file];
        bundle[newFileName] = {
          ...asset,
          fileName: newFileName,
          source: newCss,
          type: "asset"
        };
      }
    }
  };
};
export {
  index_default as default
};
